import { Component, OnInit } from '@angular/core';
import { ProjectService } from 'src/app/services/project.service';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators, FormGroup } from '@angular/forms';
import ValidationUtils from 'src/app/utils/validation';
import { environment } from 'src/environments/environment';

@Component({
  selector: 'app-new-project',
  templateUrl: './new-project.component.html',
  styleUrls: ['./new-project.component.css']
})
export class NewProjectComponent implements OnInit {

  fileSeparator = `${environment.fileSeparator}`;
  formGroup: FormGroup;
  isBusy: boolean;

  constructor(private projectService: ProjectService, private _fb: FormBuilder, private router: Router, private route: ActivatedRoute) {
    this.formGroup = this._fb.group({
      projectName: ['', Validators.compose([Validators.required, Validators.maxLength(200)])],
      projectRoot: ['', Validators.compose([Validators.required, Validators.maxLength(200)])],
      testPackage: ['', Validators.compose([Validators.required, Validators.maxLength(200)])],
      testPath: ['', Validators.compose([Validators.required, Validators.maxLength(200)])],
      modelPath: [this.fileSeparator + 'src' + this.fileSeparator + 'main' + this.fileSeparator + 'resources', Validators.compose([Validators.required, Validators.maxLength(200)])],
      embeddedFilePath: [this.fileSeparator + 'src' + this.fileSeparator + 'main' + this.fileSeparator + 'webapp', Validators.compose([Validators.required, Validators.maxLength(200)])]
    })
  }

  async ngOnInit() {
  }

  async onSubmit() {
    this.isBusy = true;
    const formValue = this.formGroup.value;

    if (!this.formGroup.invalid) {
      try {
        let result = await this.projectService.createProject(formValue);
        this.router.navigate(['/project', result.id, 'loops']);
      } finally {
        this.isBusy = false;
      }
    } else {
      ValidationUtils.validateAllFormFields(this.formGroup);
      this.isBusy = false;
    }
  }
}
