import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { BPMNMock } from '../models/bpmn-mock';
import { BPMNExternalServiceMock } from '../models/bpmn-external-service-mock';
import { BPMNDelegateMock } from '../models/bpmn-delegate-mock';
import { BPMNTestcase } from '../models/bpmn-testcase';
import { VariableProposals } from '../models/variable-proposals';

@Injectable({
  providedIn: 'root'
})
export class MockService {

  constructor(public http: HttpClient) { }

  public async getMocks(projectId: number): Promise<Array<BPMNMock>> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock`;
    return <Array<BPMNMock>>await this.http.get(url).toPromise();
  }

  public async getExternalServiceMock(projectId: number, mockId: string): Promise<BPMNExternalServiceMock> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/external/${mockId}`;
    return <BPMNExternalServiceMock>await this.http.get(url).toPromise();
  }

  public async getDelegateMock(projectId: number, mockId: string): Promise<BPMNDelegateMock> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/delegate/${mockId}`;
    return <BPMNDelegateMock>await this.http.get(url).toPromise();
  }

  public async createExternalServiceMock(projectId: number, mock: BPMNExternalServiceMock): Promise<any> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/external`;
    return await this.http.post<any>(url, mock).toPromise();
  }

  public async createDelegateMock(projectId: number, mock: BPMNDelegateMock): Promise<any> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/delegate`;
    return await this.http.post<any>(url, mock).toPromise();
  }

  public async updateExternalServiceMock(projectId: number, mockId: string, mock: BPMNExternalServiceMock): Promise<any> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/external/${mockId}`;
    return await this.http.put<any>(url, mock).toPromise();
  }

  public async updateDelegateMock(projectId: number, mockId: string, mock: BPMNDelegateMock): Promise<any> {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/delegate/${mockId}`;
    return await this.http.put<any>(url, mock).toPromise();
  }

  public async deleteMock(projectId: number, mockId: string) {
    const url = `${environment.apiBaseUrl}project/${projectId}/mock/${mockId}`;
    return await this.http.delete(url).toPromise();
  }

  public async getVariableInfo(projectId: number): Promise<Array<VariableProposals>> {
    const url = `${environment.apiBaseUrl}project/${projectId}/variable/info`;
    return <Array<VariableProposals>>await this.http.get(url).toPromise();
  }
}
